@@ -4,11 +4,12 @@ R objects as Python objects.
 The module is structured around the singleton r of class R,
 that represents an embedded R.
 
-License: GPLv3.0 (although a dual license can be worked out)
+License: GPLv2+
 
 """
 
 import os, sys
+import types
 import array
 import itertools
 from datetime import datetime
@@ -40,7 +41,8 @@ from rpy2.rinterface import (Sexp,
                              SexpVector, 
                              SexpClosure, 
                              SexpEnvironment, 
-                             SexpS4, 
+                             SexpS4,
+                             StrSexpVector,
                              SexpExtPtr)
 _globalenv = rinterface.globalenv
 
@@ -62,6 +64,7 @@ else:
     py3str = str
     py3bytes = bytes
 
+_rparse = rinterface.baseenv['parse']
 _reval = rinterface.baseenv['eval']
 
 def reval(string, envir = _globalenv):
@@ -74,7 +77,7 @@ def reval(string, envir = _globalenv):
     res = _reval(p, envir = envir)
     return res
 
-default_converter = conversion.make_converter('base empty converter')
+default_converter = conversion.Converter('base empty converter')
 
 @default_converter.ri2ro.register(RObject)
 def _(obj):
@@ -107,6 +110,8 @@ def sexpvector_to_ro(obj):
                 res = vectors.POSIXct(obj)
             else:
                 res = vectors.FloatVector(obj)
+        elif obj.typeof == rinterface.LGLSXP:
+            res = vectors.BoolVector(obj)
         elif obj.typeof == rinterface.STRSXP:
             res = vectors.StrVector(obj)
         elif obj.typeof == rinterface.VECSXP:
@@ -236,6 +241,15 @@ def _(obj):
     robj = conversion.py2ri(obj)
     return conversion.ri2ro(robj)
 
+@default_converter.py2ri.register(types.FunctionType)
+def _function_to_ri(func):
+    def wrap(*args):
+        res = func(*args)
+        res = conversion.py2ro(res)
+        return res
+    rfunc = rinterface.rternalize(wrap)
+    return rfunc
+
 @default_converter.ri2py.register(object)
 def _(obj):
     return conversion.ri2ro(obj)
@@ -271,8 +285,36 @@ class Formula(RObjectMixin, rinterface.Sexp):
                            "R environment in which the formula will look for" +
                            " its variables.")
 
+    
+class ParsedCode(rinterface.SexpVector):
+    def __init__(self, source=None):
+        self._source = source
+        super(ParsedCode, self).__init__(self)
+
+    @property
+    def source(self):
+        return self._source
+
+    
+class SourceCode(str):
+    
+    def parse(self, keep_source=True):
+        res = _rparse(text=rinterface.StrSexpVector((self,)))
+        if keep_source:
+            res = ParsedCode(res, source=self)
+        else:
+            res = ParsedCode(res, source=None)
+        return res
+    
+    def as_namespace(self, name):
+        """ Name for the namespace """
+        return SignatureTranslatedAnonymousPackage(self,
+                                                   name)
 
 class R(object):
+    """
+    Singleton representing the embedded R running.
+    """
     _instance = None
 
     def __new__(cls):
@@ -294,7 +336,7 @@ class R(object):
 
     def __getitem__(self, item):
         res = _globalenv.get(item)
-        res = conversion.ri2ro(res)
+        res = conversion.ri2py(res)
         if hasattr(res, '__rname__'):
             res.__rname__ = item
         return res
@@ -313,21 +355,15 @@ class R(object):
         return s
 
     def __call__(self, string):
-        p = rinterface.parse(string)
+        p = _rparse(text=StrSexpVector((string,)))
         res = self.eval(p)
-        return res
+        return conversion.ri2py(res)
 
 r = R()
 
-conversion.converter = default_converter
-converter_name, conversion.ri2ro, conversion.py2ri, conversion.py2ro, conversion.ri2py, converter_lineage = conversion.converter
+conversion.set_conversion(default_converter)
 
-default_ri2ro = conversion.converter.ri2ro
-default_py2ri = conversion.converter.py2ri
-default_py2ro = conversion.converter.py2ro
-default_ri2py = conversion.converter.ri2py
-
-globalenv = conversion.ri2ro(_globalenv)
-baseenv = conversion.ri2ro(rinterface.baseenv)
-emptyenv = conversion.ri2ro(rinterface.emptyenv)
+globalenv = conversion.converter.ri2ro(_globalenv)
+baseenv = conversion.converter.ri2ro(rinterface.baseenv)
+emptyenv = conversion.converter.ri2ro(rinterface.emptyenv)
 
