@@ -170,14 +170,14 @@ class VectorTestCase(unittest.TestCase):
     def testRepr(self):
         vec = robjects.IntVector((1,2,3))
         s = repr(vec).split('\n')
-        self.assertEqual('[       1,        2,        3]', s[1])
+        self.assertEqual('[       1,        2,        3]', s[2])
 
     def testReprNonVectorInList(self):
         vec = robjects.ListVector(OrderedDict((('a', 1), 
                                                ('b', robjects.Formula('y ~ x')),
                                                )))
         s = repr(vec).split('\n')
-        self.assertEqual('[IntVector, Formula]', s[1].strip())
+        self.assertEqual('[IntVector, Formula]', s[2].strip())
 
     def testItems(self):
         vec = robjects.IntVector(range(3))
@@ -283,6 +283,15 @@ class ExtractDelegatorTestCase(unittest.TestCase):
     def tearDown(self):
         robjects.rinterface.set_writeconsole_regular(self.console)
 
+        
+    def testFloorDivision(self):
+        v = robjects.vectors.IntVector((2,3,4))
+        if sys.version_info[0] == 2:
+            res = v.ro / 2
+        else:
+            res = v.ro // 2
+        self.assertEqual((1,1,2), tuple(int(x) for x in res))
+            
     def testExtractByIndex(self):
         seq_R = robjects.baseenv["seq"]
         mySeq = seq_R(0, 10)
@@ -382,6 +391,7 @@ class ExtractDelegatorTestCase(unittest.TestCase):
         self.assertTrue(idem(letters, myList.rx("l")[0]))
         self.assertTrue(idem("foo", myList.rx("f")[0]))
 
+
 class ConversionHelperTestCase(unittest.TestCase):
 
     def testSequenceToVector(self):
